# pyPCoA

`pyPCoA`は、JaccardおよびBray-Curtis距離を使用して主座標分析（PCoA）を行うPythonパッケージです。

## 特徴

- Excelファイルからデータを読み込み
- Bray-Curtis距離の計算(Jaccardの計算は次のversionで可能にします。近日公開)
- PCoAの実行と結果の保存

## インストール

```bash
pip install pyPCoA
